#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for GNU Typist -- well known typing tutor.
#---( Source URL: http://ufpr.dl.sourceforge.net/sourceforge/aiksaurus/aiksaurus-1.2.1.tar.gz
#---( Build script by R S Ananda Murthy (rsamurti@airtelbroadband.in)
#---( Date build script was last modified: Saturday, October 7, 2006


#------------------( Set Package Name & Version )


soft='aiksaurus'
softversion='1.2.1'
packageversion='1rsa'


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS )


chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu" 


#------------------( Configure, Make And Install The Software )


cd $src

./configure --prefix=/usr \
--bindir=/usr/bin \
--mandir=/usr/man 

make DESTDIR=$dest
make install DESTDIR=$dest


#------------------( Strip Executables (Comment out these lines if debugging info is needed) )


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)

( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)


#------------------( Compress Man Pages and Info Pages and Move To Correct Location )


( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

( cd $dest/usr/info
  find . -name "*.info" | xargs gzip -9
  rm -f dir
)


#------------------( Move Documentation To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS COPYING NEWS README INSTALL \
  $dest/usr/doc/$soft-$softversion
cp $src/doc/*.htm* $dest/usr/doc/$soft-$softversion

rm -rf $dest/usr/share/doc


#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( We Made A Custom Icon, Let's Copy It For Next Time )


cp $buildir/aiksaurus.png $dest/usr/src/$soft-$softversion/aiksaurus.png


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
         |-----handy-ruler------------------------------------------------------|
aiksaurus: Aiksaurus (A thesaurus)
aiksaurus: 
aiksaurus: This is a  set of libraries and applications which provide a thesaurus
aiksaurus: (currently English only, based on Guttenburg's Moby thesaurus) using
aiksaurus: native GUI on several platforms: UNIX (GTK+ & Qt), Win32 & MacOSX
aiksaurus: (Cocoa). The core library itself is platform-independent.
aiksaurus: The principal language is C++, with some use of Cocoa/ObjC++;
aiksaurus: wrappers are provided for C and Cocoa/ObjC.
aiksaurus: 
aiksaurus: 
aiksaurus: Packaged by R S Ananda Murthy on a Slackware 11 system.
EOF

#------------------( Create The Desktop Menu Entry )

mkdir -p $dest/usr/share/applications
cat <<EOF > $dest/usr/share/applications/$soft.desktop
[Desktop Entry]
Encoding=UTF-8
Name=AikSaurus
Comment=Free Thesaurus
Exec=gaiksaurus
Terminal=false
Type=Application
Categories=Application;Office;
Icon=aiksaurus.png
StartupNotify=true
EOF

#------------------( Copy The Icon To The Correct Location )


mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
cp $buildir/aiksaurus.png $dest/usr/share/icons/hicolor/48x48/apps/aiksaurus.png


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tgz > $package.md5